@@ -11,16 +11,18 @@ NULL
 #'
 #' @param x a string
 #' @param y a string
+#'
 #' @examples
-#' ("ab" \%+\% "c") == "abc" # TRUE
-#' ("abc" \%-\% "b") == "ac" # TRUE
-#' ("ac" \%s*\% 2) == "acac" # TRUE
-#' ("acac" \%s/\% "c") == 2  # TRUE
+#' ("ab" %+% "c") == "abc" # TRUE
+#' ("abc" %-% "b") == "ac" # TRUE
+#' ("ac" %s*% 2) == "acac" # TRUE
+#' ("acac" %s/% "c") == 2  # TRUE
 #' # String division with a regular expression:
 #' 'an apple a day keeps the malignant spirit of Steve Jobs at bay' %s/% 'Steve Jobs|apple'
 #'
-#' @rdname string_arithmetic
-
+#' @author Ben Wiseman, \email{benjamin.wiseman@@kornferry.com}
+#' @name string_arithmetic
+NULL
 
 #' @rdname string_arithmetic
 #' @export
@@ -34,7 +36,7 @@ NULL
   unname(mapply(function(x,y) gsub(pattern = y, replacement = '', x = x), x, y))
 }
 
-#Added in ulrike's suggestion for making compatible with vector or scalar input
+# Added in ulrike's suggestion for making compatible with vector or scalar input
 #' @rdname string_arithmetic
 #' @export
 `%s*%`  <- function(x, y) {
@@ -51,7 +53,6 @@ NULL
 }
 
 
-
 #### For assignment operators  ------------------
 
 #### Apply mathematical operator and reassignment
@@ -61,18 +62,20 @@ NULL
 #' @description
 #' Modifies the stored value of the left-hand-side object by the right-hand-side object.
 #' Equivalent of operators such as \code{+=} \code{-=} \code{*=} \code{/=} in languages like c++ or python.
-#' \code{\%+=\%} and \code{\%-=\%} can also work with strings.
+#' \code{%+=%} and \code{%-=%} can also work with strings.
 #'
 #' @param x a stored value
 #' @param y value to modify stored value by
+#'
+#' @author Ben Wiseman, \email{benjamin.wiseman@@kornferry.com}
 #' @examples
 #' x <- 1
 #'
-#' x \%+=\% 2
+#' x %+=% 2
 #'
 #' x == 3 # TRUE
 #'
-#' x \%-=\% 3
+#' x %-=% 3
 #'
 #' x == 0 # TRUE
 #'
@@ -80,64 +83,64 @@ NULL
 #' test <- iris
 #'
 #' # Simply modify in-place
-#' test$Sepal.Length[test$Species == 'setosa' & test$Petal.Length < 1.5] \%+=\% 1
+#' test$Sepal.Length[test$Species == 'setosa' & test$Petal.Length < 1.5] %+=% 1
 #'
 #' # Which is much nicer than typing:
 #' test$Sepal.Length[test$Species == 'setosa' & test$Petal.Length < 1.5] <-
 #' test$Sepal.Length[test$Species == 'setosa' & test$Petal.Length < 1.5] + 1
 #' # ...which is over the 100 character limit for R doccumentation!
 #'
-#' # \%+=\% and \%-=\% also work with strings
+#' # %+=% and %-=% also work with strings
 #'
 #'    x <- "ab"
 #'
-#'    x \%+=\% "c"
+#'    x %+=% "c"
 #'
-#'    x \%-=\% "b"
+#'    x %-=% "b"
 #'
 #'    x == "ac" # TRUE
 #'
-#' # \%-=\% can also take regular expressions
+#' # %-=% can also take regular expressions
 #'
 #'    x <- "foobar"
 #'
-#'    x \%-=\% "[f|b]"
+#'    x %-=% "[f|b]"
 #'
 #'    print(x)
 #'    # "ooar"
-#' @rdname assign_ops
+#' @name assign_ops
+NULL
 
 #' @rdname assign_ops
 #' @export
 `%+=%`   <- function(x, y){
   if(is.character(x) | is.character(y)){
-    #.create_operator(x, y, `\%+\%`)
+    #.create_operator(x, y, `%+%`)
     v_name  <- substitute(x)
     v_value <- paste0(x,y)
     eval(call("<-", v_name, v_value), envir = parent.frame(n = 1))
-    }
-  else{
+  } else {
     #.create_operator(x, y, `+`)
     v_name  <- substitute(x)
     v_value <- x+y
     eval(call("<-", v_name, v_value), envir = parent.frame(n = 1))
-    }
+  }
 }
 
 #' @rdname assign_ops
 #' @export
 `%-=%`  <- function(x, y){
   if(is.character(x) | is.character(y)){
-    #.create_operator(x, y, `\%-\%`)
+    #.create_operator(x, y, `%-%`)
     v_name  <- substitute(x)
     v_value <- gsub(y, '', x)
     eval(call("<-", v_name, v_value), envir = parent.frame(n = 1))
-    } else{
+  } else{
       #.create_operator(x, y, `-`)
       v_name  <- substitute(x)
       v_value <- x-y
       eval(call("<-", v_name, v_value), envir = parent.frame(n = 1))
-    }
+  }
 }
 
 #' @rdname assign_ops
@@ -191,10 +194,11 @@ NULL
 #' This takes two arguments just like \code{gsub} - a patterns and a replacement.
 #' It will only overwrite the parts of any character where the pattern is matched with the second argument.
 #' If you want to overwrite whole elements via a regex (i.e. replace the entire element if it matches),
-#' use \code{\%regex<-\%} instead.
+#' use \code{%regex<-%} instead.
 #'
 #' @param x a character vector
 #' @param value c(pattern, replacement)
+#'
 #' @examples
 #' # Apply a regular expression/substitution to x:
 #'
@@ -202,15 +206,16 @@ NULL
 #'
 #'  # change any number to "x"
 #'
-#'   x \%regex=\% c("\\d+", "x")
+#'   x %regex=% c("\\d+", "x")
 #'
 #'  print(x)
 #'
 #'  # "axb" "b" "c" "dx"
+#' @author Ben Wiseman, \email{benjamin.wiseman@@kornferry.com}
 #' @rdname overwrite_by_regex
 #' @export
 `%regex=%`<- function(x, value){
-  if(length(value) != 2) warning("right-hand-side isn't length 2 but it MUST be in the form c(pattern, replacement)")
+  if(length(value) != 2) warning("roperators: \n right-hand-side isn't length 2 but it MUST be in the form c(pattern, replacement)")
   v_name  <- substitute(x) #with user defined functions, can't run in parent frame
   v_value <- gsub(value[1], value[2], x)
   eval(call("<-", v_name, v_value), envir = parent.frame(n = 1))
@@ -226,11 +231,12 @@ NULL
 #' This takes two arguments just like \code{gsub} - a patterns and a replacement.
 #' It will totally overwrite any element where the pattern is matched with the second.
 #' If you want to simply apply a regex (i.e. replace only the specific bit that matches),
-#' use \code{\%regex=\%} instead. If you want to replace with nothing (""), just just \code{\%-\%} or
-#' \code{\%-=\% instead}.
+#' use \code{%regex=%} instead. If you want to replace with nothing (""), just just \code{%-%} or
+#' \code{%-=% instead}.
 #'
 #' @param x a character vector
 #' @param value c(pattern, replacement)
+#'
 #' @examples
 #' # Overwrite elements that match regex:
 #'
@@ -243,10 +249,11 @@ NULL
 #'  print(x)
 #'
 #'  # "x" "b" "c" "x"
+#' @author Ben Wiseman, \email{benjamin.wiseman@@kornferry.com}
 #' @rdname assign_by_regex
 #' @export
 `%regex<-%`<- function(x, value){
-  if(length(value) != 2) warning("right-hand-side isn't length 2 but it MUST be in the form c(pattern, replacement)")
+  if(length(value) != 2) warning("roperators: \n right-hand-side isn't length 2 but it MUST be in the form c(pattern, replacement)")
   v_name  <- substitute(x) #with user defined functions, can't run in parent frame
   idx <- grep(value[1], x)
   v_value <- x
@@ -260,11 +267,12 @@ NULL
 #' Assign value to a vector's missing values
 #'
 #' @description
-#' \code{\%na<-\%} is a simple shortcut to assign a specific value to all
+#' \code{%na<-%} is a simple shortcut to assign a specific value to all
 #' NA elements contained in x.
 #'
 #' @param x a vector
 #' @param value value to replace vector's missing values with
+#'
 #' @examples
 #'  x <- c("a", NA, "c")
 #'
@@ -279,12 +287,20 @@ NULL
 #'
 #'  print(x)
 #'  # 1 2 3 4
-#'
+#' @author Ben Wiseman, \email{benjamin.wiseman@@kornferry.com}
 #' @rdname overwrite_missing
 #' @export
 `%na<-%` <- function(x, value) {
-  v_name  <- substitute(x) #with user defined functions, can't run in parent frame
-  x[is.na(x)] <- value
+  v_name <- substitute(x)
+  if (is.scalar(value)) {
+    x[is.na(x)] <- value
+  } else {
+    i <- which(is.na(x))
+    if(length(x) != length(value)){
+      warning('roperators: \n using a replacement vector of unequal size')
+    }
+    x[i] <- value[i]
+  }
   v_value <- x
   eval(call("<-", v_name, v_value), envir = parent.frame(n = 1))
 }
@@ -297,20 +313,25 @@ NULL
 #' @description
 #' These operators introduce improved NA handling, reliable floating point tests,
 #' and intervals. Specifically:
-#'\itemize{
-#'  \item{Equality that handles missing values}
-#'  \item{Floating point equality, an important bit of functionality missing in base R (\code{\%~=\%})}
-#'  \item{Strict (value and type) equality, for those familiar with Javascript's \code{===}}
-#'  \item{Greater/less than or equal to with missing value equality}
-#'  \item{Greater/less than or equal to with floating point and missing equality}
-#'  \item{Between (ends excluded)}
-#'  \item{Between (ends included)}
-#'}
+#'
+#'  Equality that handles missing values
+#'
+#'  Floating point equality, an important bit of functionality missing in base R (\code{%~=%})
+#'
+#'  Strict (value and type) equality, for those familiar with Javascript \code{===}
+#'
+#'  Greater/less than or equal to with missing value equality
+#'
+#'  Greater/less than or equal to with floating point and missing equality
+#'
+#'  Between (ends excluded)
+#'
+#'  Between (ends included)
 #'
 #' @param x a vector
 #' @param y a vector
-#' @examples
 #'
+#' @examples
 #'  ## Greater/Less than | Equal
 #'
 #'  c(1, NA, 3, 4)  ==  c(1, NA, 4, 3)
@@ -357,10 +378,9 @@ NULL
 #'  3 %>=<% c(1, 3)
 #'  # TRUE
 #'
-#'
-#' @rdname comparisons
-#' @export
-
+#' @author Ben Wiseman, \email{benjamin.wiseman@@kornferry.com}
+#' @name comparisons
+NULL
 
 #' @rdname comparisons
 #' @family comparisons
@@ -403,7 +423,7 @@ NULL
 #' @rdname comparisons
 #' @export
 `%><%` <- function(x, y){
-  if(length(y) != 2) warning("right-hand-side isn't length 2 but it MUST be in the form c(lower_bound, upper_bound)")
+  if(length(y) != 2) warning("roperators: \n  right-hand-side isn't length 2 but it MUST be in the form c(lower_bound, upper_bound)")
   x > y[1] & x < y[2]
 }
 
@@ -411,14 +431,13 @@ NULL
 #' @rdname comparisons
 #' @export
 `%>=<%`<- function(x, y){
-  if(length(y) != 2) warning("right-hand-side isn't length 2 but it MUST be in the form c(lower_bound, upper_bound)")
+  if(length(y) != 2) warning("roperators: \n right-hand-side isn't length 2 but it MUST be in the form c(lower_bound, upper_bound)")
   x >= y[1] & x <= y[2]
 }
 
 #'  Floating point comparison operators
 #'
 #'@description
-#'
 #'  These are an important set of operators missing from base R. In particular,
 #'  using \code{==} on two non-interger numbers can give unexpected results (see examples.)
 #'
@@ -426,7 +445,8 @@ NULL
 #'  \url{https://docs.oracle.com/cd/E19957-01/806-3568/ncg_goldberg.html}
 #' @param x numeric
 #' @param y numeric
-#'@examples
+#'
+#' @examples
 #'  ## Floating point test of equality ####
 #'
 #'  # Basic Equality - no roperators:
@@ -443,10 +463,9 @@ NULL
 #'  (0.1 + 0.1 + 0.1) %>~% 0.3 # TRUE
 #'  (0.1 + 0.1 + 0.1) %<~% 0.3 # TRUE
 #'
-#'
-#' @rdname floating_point_comparisons
-#' @export
-
+#' @author Ben Wiseman, \email{benjamin.wiseman@@kornferry.com}
+#' @name floating_point_comparisons
+NULL
 
 #' @rdname floating_point_comparisons
 #' @family comparisons
@@ -481,8 +500,8 @@ NULL
 #'
 #' @param x a vector
 #' @param y a vector
-#' @examples
 #'
+#' @examples
 #'  #### Not in ####
 #'
 #'  "z" %ni%  c("a", "b", "c")
@@ -510,27 +529,25 @@ NULL
 #'  FALSE %aon% TRUE
 #'  # FALSE
 #'
-#' @rdname logicals
-#' @export
+#' @author Ben Wiseman, \email{benjamin.wiseman@@kornferry.com}
+#' @name logicals
+NULL
 
-
-
-
-#' Not in
+# Not in
 #' @rdname logicals
 #' @export
 `%ni%` <- function(x, y) {
   !(x %in% y)
 }
 
-#' exclusive or
+# Exclusive or
 #' @rdname logicals
 #' @export
 `%xor%`<- function(x, y){
   xor(x, y)
 }
 
-#' All or nothing
+# All or nothing
 #' @rdname logicals
 #' @export
 `%aon%`<- function(x, y){
@@ -539,10 +556,71 @@ NULL
 
 
 
-
-#################              MISC                               ##############
+#' mySQL-like rlike
+#'
+#' @description
+#' This takes two arguments just like \code{grepl} - a string and a pattern.
+#' TRUE if \code{grepl(pattern, x, ignore.case=TRUE)} would be TRUE
+#'
+#' @note
+#' data.table has a %like% operator which you should try to use instead if working with data.table!
+#'
+#' @param x a character vector
+#' @param pattern a single character expression
+#'
+#' @examples
+#' # Apply a regular expression/substitution to x:
+#'
+#'  x <- c("foo", "bar", "dOe", "rei", "mei", "obo")
+#'
+#'  # where x has an O
+#'
+#'  x[x %rlike% "O"]
+#'
+#'  # [1] "foo" "dOe" "obo"
+#'
+#'  # find x where middle letter is "O"
+#'
+#'  x[x %rlike% "[a-z]O[a-z]"]
+#'
+#'  # will print [1] "foo" "dOe"
+#'
+#' @rdname logicals
+#' @export
+`%rlike%`<- function(x, pattern){
+  if(length(pattern) != 1) rop_stop("right-hand-side isn't length 1 but it MUST be")
+  grepl(pattern, x, ignore.case = TRUE)
+}
 
 
 
+#' SQL-like like
+#'
+#' @description
+#' This takes two arguments just like \code{grepl} - a string and a pattern.
+#' TRUE if \code{grepl(pattern, x, ignore.case=FALSE, perl=TRUE)} would be TRUE.
+#' It's like \code{%like%} from data.table (but slower, preferably use data.table).
+#'
+#'
+#' @param x a character vector
+#' @param pattern a single character expression
+#'
+#' @examples
+#' # Apply a regular expression/substitution to x:
+#'
+#'  x <- c("foo", "bar", "dOe", "rei", "mei", "obo")
+#'
+#'  # find x where middle letter is upper-case "O"
+#'
+#'  x[x %perl% "[a-z]O[a-z]"]
+#'
+#'  # will print [1] "dOe"
+#'
+#' @rdname logicals
+#' @export
+`%perl%`<- function(x, pattern){
+  if(length(pattern) != 1) rop_stop("right-hand-side isn't length 1 but it MUST be")
+  grepl(pattern, x, ignore.case=FALSE, perl = TRUE)
+}
+
 
-###############################################################################
\ No newline at end of file
